@@ -1,7 +1,10 @@
 #[macro_use]
 mod test;
 
+mod assert_stdout;
+mod assert_success;
 mod common;
+mod tempdir;
 
 mod choose;
 mod command;
@@ -15,6 +18,7 @@ mod evaluate;
 mod examples;
 mod export;
 mod fmt;
+mod functions;
 mod init;
 mod interrupts;
 mod invocation_directory;
@@ -26,4 +30,5 @@ mod search;
 mod shebang;
 mod shell;
 mod string;
+mod sublime_syntax;
 mod working_directory;
